<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/* Author: Creative Services, College of William and Mary
*/
class SM_Directory extends CI_Controller {

	public function __construct() {
		parent::__construct();
		
		$this->data["categoryOptions"] = $this->getCategories();
		$this->data["shortCategoryOptions"] = $this->getShortCategories();
		$this->data["smtypeOptions"] = $this->getSMTypes();
		$this->data["smUrls"] = $this->getURLs();
		$this->data["schoolOptions"] = $this->getSchools();
		$this->data["dirTypes"] = $this->getDirTypes();
		$this->data["filterOptions"] = array("name"=>"Name", "category"=>"Category", "type"=>"Type", "school"=>"School");
	}
	
	private function getCategories() {
		$cats = $this->directory_model->getCategories();
		$toRet = array();
		foreach ($cats as $c) {
			$toRet[$c["id"]] = $c["full_name"];
		}
		return $toRet;
	}
	
	private function getShortCategories() {
		$cats = $this->directory_model->getCategories();
		$toRet = array();
		foreach ($cats as $c) {
			$toRet[$c["id"]] = $c["short_name"];
		}
		return $toRet;
	}
	
	private function getSMTypes() {
		$cats = $this->directory_model->getSMTypes();
		$toRet = array();
		foreach ($cats as $c) {
			$toRet[$c["id"]] = $c["name"];
		}
		return $toRet;
	}
	
	private function getDirTypes() {
		return $this->directory_model->getDirTypes();
	}
	
	private function getURLs() {
		$cats = $this->directory_model->getSMTypes();
		$toRet = array();
		foreach ($cats as $c) {
			$toRet[$c["id"]] = $c["base_url"];
		}
		return $toRet;
	}

	private function getSchools() {
		$cats = $this->directory_model->getSchools();
		$toRet = array();
		foreach ($cats as $c) {
			$toRet[$c["id"]] = $c["name"];
		}
		return $toRet;
	}
	
	public function index($viewBy = "")	{
		$this->official($viewBy);
	}
	
	public function official($viewBy = "")	{
		$this->viewDirectoryList("official", $viewBy);
	}
	
	public function officialish($viewBy = "") {
		$this->viewDirectoryList("officialish", $viewBy);
	}
	
	public function unofficial($viewBy="") {
		$this->viewDirectoryList("unofficial", $viewBy);
	}
	
	/** Return an alphabetical list of entities with all of their associated accounts, 
		or return the accounts sorted by social media type, entity category or entity school **/
	private function viewDirectoryList($type, $viewBy="") {
		$this->data["thisPage"] = $type;
		if (!in_array($viewBy, array("name", "category", "type", "school"))) {
			$viewBy = "name";
		}
		$this->data["viewBy"] = $viewBy;
		$es = $this->directory_model->getEntitiesByType($type, $viewBy);
		$eIds = array();
		foreach ($es as $e) {
			$eIds[] = $e["id"];
		}
		$as = $this->directory_model->getAccountsByEntity($eIds);
		if ($viewBy == "type") {
			$eById = array();
			// create array of entities indexed by their ID
			foreach ($es as $e) {
				$eById[$e["id"]] = $e;
			}
			$tO = $this->data["smtypeOptions"];
			$actsByC = array();
			// Create array of accounts indexed by social media type
			foreach ($tO as $tId => $tName) {
				$actsByC[$tId] = array();
			}
			foreach ($as as $a) {
				$actsByC[$a["smtype_id"]][$eById[$a["entity_id"]]["name"]] = $a;
			}
			foreach ($actsByC as $aC=>$aList) {
				$sortedList = $aList;
				ksort($sortedList);
				$this->data["accounts"][$aC] = $sortedList;
			}
			$this->data["entities"] = $eById;
		} else {
			$aIds = array();
			// create array of accounts by their entity IDs
			foreach ($as as $a) {
				$aIds[$a["entity_id"]][] = $a;
			}
			$eToRet = array();
			foreach ($es as $e) {
				if (isset($aIds[$e["id"]])) { // handle if there is an entity with no active accounts
					$tmpE = $e;
					$tmpE["accounts"] = $aIds[$e["id"]];
					if (!empty($tmpE["accounts"])) {
						$eToRet[] = $tmpE;	
					}
				}
				
			}
			$this->data["entities"] = $eToRet;
		}
		$this->load->view('directory', $this->data);
	}
}

/* End of file sm_directory.php */
